bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 15. Aventiure
___________________________________________________ #### <Wie Sifrit verraten wart>
| ### n dem vierden morgen zwen vnd drizech man ### sach man ze hove riten daz wart do kvnt getan ### Gvnther dem richen im were widerseit [34a] ### von luge wuohs den frovwen grozer iamer vn– leit
###### 821 | ### Vrlovp si gewunnen daz si fur solden gan ### vnd iahen daz siz weren Liudgers man ### den ê da hete betwungen Sifrides hant ### vnd in ce gisle brehte in Gvnthers lant
###### 822 | ### Die boten er do gruozte vn– hiez si sicen gan ### einer sprach darunder herre lat vns stan ### vnz wir gesagen mere div iv enboten sint ### ia habet ir ce viende daz wizzet maniger muoter kint
###### 823 | ### Iv widerseit Livdegast vnd Livdger ### den ir da willen <tatet> gremlichiv ser ### die wellent zuo iv riten mit her in dice lant ### der kvnich begvnde zvrnen do er div mere bevant
###### 824 | ### Man hiez die meinræten zern herbergen varn ### wie mohte sich Syfrit da vor do bewarn ### er oder ander ieman daz si do truogen an ### daz wart sid in selben ce grozem leide getan
###### 825 | ### Der kvnich mit sinen frivnden ruonende gie ### Hagne von Trony in nie geriwen lie ### nach heten ez gesceiden des kvniges man ### do wolde et Hagne nie des rates abe gan
###### 826 | ### Eins tages si Sifrit ruonende vant ### do begvnde vragen der helt von Niderlant ### wie gat so truoreclichen der kvnich vnd sine man ### daz hilfe ich immer reken hat in ieman iht getan
###### 827 | ### Do sprach kvnich Gvnther mir ist von schvlden leit ### Liudgast vnd Livdger habent mir widerseit ### si wellen offenliche riten in min lant ### do sprach der degen kvene daz sol Sifrides hant
###### 828 | ### nach allen ivren eren mit flize vnderstan ### ich tuon noch degenen als ich in ê han getan ### ich lege in wueste ir burge vnd ovch ir lant ### ê daz ich erwinde des si min hovbet iwer phant
###### 829 | ### Ir vnd iwer reken svlt hie heim bestan ### vnde lat mich zuo in riten mit den die ich han ### daz ich iv gerne diene daz laze ich iv sehen ### von mir sol iwern vienden wizzet leide geschehen
###### 830 | ### So wol mich dirre mere sprach der kvnich do ### als ob er ernsliche der helfe were vro ### in valsche neig im tiefe der vngetriwe man ### do sprach der herre Sifrit ir svlt kleine sorge han
###### 831 | ### Do schikten si die reise mit den knehten dan ### Sifride vnd den sinen ce sehenne ez was getan ### do hiez er sich bereiten die von Niderlant ### Sifrides reken suohten stritlich gewant
###### 832 | ### Do sprach der starke Sifrit vater min her Sigmvnt ### ir svlt hie beliben wir komen in kurzer stvnt ### git vns got geluke her wider an den Rin ### ir svlt bi dem kvnige hie vil vrolichen sin
###### 833 | ### Diu zeiken si ane bvnden alse si wolden dan [34b] ### do waren da genuoge Gvnthers man ### die wessen niht der mere wa von ez was geschehen ### man mohte groz gesinde do bi Sifride sehen
###### 834 | ### Ir helme vnd ovch ir brvnne si bvnden vf div march ### sich bereite von dem lande manich riter starch ### do gie von Trony Hagne da er Kriemhilde vant ### er bat im geben vrlovp si wolden rvmen daz lant
###### 835 | ### Wol mich sprach Chriemhilt daz ich ie den man gewan ### der minen lieben vrivnden so wol tar vor stan ### alse min her Sifrit tuot den frivnden min ### des wil ich hohes muotes sprach div kvnniginne sin
###### 836 | ### Lieber friunt er Hagene degenket an daz ### daz ich in gerne diene vnd noch nie wart gehaz ### des lat mich geniezen an minen lieben man ### er sol des niht enkelten hab ich Prunhilt iht getan
###### 837 | ### Daz hat mich sit gerowen sprach daz edel wip ### ovch hat er so zerblovwen darvmbe minen lip ### daz ichz iê gereite daz beswarte im den mvot ### daz hat vil wol erroken der degen kuene vnde guot
###### 838 | ### Er sprach ir werdet wol versuenet her nach disen tagen ### Kriemhilt liebiv vrowe ia sult ir mir sagen ### wie ich iv mvge dienen an Sifride iwern man ### daz tuon ich gerne frovwe baz ichs nieman engan
###### 839 | ### Ich were an alle sorge sprach do daz edel wip ### daz im ieman neme in stvrme sinen lip ### ob er niht wolde volgen siner vbermvot ### so were immer sicher der degen kuene vnde guot
###### 840 | ### Vrowe sprach do Hagne vn– habet ir des wan ### daz man in mvge versniden ir svlt mich wizzen lan ### mit wie getanen listen sol ichz vndersten ### ich wil im ze huote immer riten vnde gen
###### 841 | ### Si sprach dv bist min mach so bin ich der din ### ich bevilhe dir vf triwe man den lieben min ### daz dv wol behuetest mir den lieben man ### si seit im kvndiv mere div vil bezzer wæren verlan
###### 842 | ### Si sprach min man ist kuene dar zuo starch genuoch ### do er den lintdrachen an deme berge sluoch ### ia badete sich der reke in dem bluote vil gemeit ### da von in seit in stvrmen kein wafen nie versneit
###### 843 | ### Idoch bin ich in sorgen swenne er in strite stat ### vnd vil der gersuzze von helde hande gat ### daz ich da verliese den minen lieben man ### hei waz ich grozer sorge dike vmb Sifriden han
###### 844 | ### Ich melde ez vf genade vil lieber frivnt dir ### daz dv dine triwe behaltest ane mir ### da man da mach verhowen den minen lieben man ### daz laze ich dich hoeren dest vf genade getan
###### 845 | ### Do von des draken bluote ### sich der riter guot ### do viel im zwischen der herte ein linden blat vil breit ### da mac in versniden des han ich sorge vnde leit [35a]
###### 846 | ### Do sprach von Trony Hagene vf daz sin gewant ### nat ein cleinez zeichen da bi ist mir bekant ### wa ich in mvge behueten so wir in sturmen stan ### si wande den helt vristen ez was vf sinen tot getan
###### 847 | ### Si sprach mit kleinen siden ne ich vf sin gewant ### ein tovgenlichez crivze da sol helt din hant ### minen man behuoten so ez an die herte gat ### swenne er in den stvrmen vor sinen vienden stat
###### 848 | ### Daz tuon ich sprach do Hagene vil liebiv vrovwe min ### do wand ovch div vrovwe ez sold im frume sin ### do was da mite verraten der Kriemhilde man ### vrlovp nam do Hagene do gie er vroelichen dan
###### 849 | ### Des kvniges ingesinde was allez wol gemvot ### ich wene nimmer reke deheiner mer getuot ### so groze meinræte so da von im ergie ### do sich an sine triwe div schoene kvnnigin verlie
###### 850 | ### Des anderen morgens mit tvsent siner man ### reit der herre Sifrit vil frovlichen dan ### er wand er solde reken der sinen frivnde leit ### Hagene im reit so <nahen> daz er geschovwe div cleit
###### 851 | ### Als er gesach daz bilde do scicte er tovgen dan ### die seiten andriv mere zwene siner man ### mit vride solde beliben daz Gvnthers lant ### vnd si hete Livdger zuo dem kvnige gesant
###### 852 | ### O wie ungerne Sifrit do hin wider reit ### er enhete ê geroken siner frivnde leit ### wan in der reise erwanden vil kvme Gvnthers man ### er reit zuo dem kvnige der wirt im danken began
###### 853 | ### Nv lon iv got des willen vriunt her Sifrit ### daz ir so willechlichen tuot des ich iv bit ### daz sol ich immer dienen als ich von rehte sol ### fur alle mine vriunde getrowe ich iv wol
###### 854 | ### Nv wir der herverte ledech worden sin ### so wil ich iagen riten bern vnd swin ### hin ce dem was kein walde als ich vil dike han ### daz hete geraten Hagne der vil vngetriwe man
###### 855 | ### Allen minen gesten sol man daz nv sagen ### ich welle fruo riten die wellen mit mir iagen ### daz sich die bereiten die wellen hie bestan ### hubschen mit den vrovwen daz si liep mir getan
###### 856 | ### Do sprach der starke Sifrit mit herliken site ### swenne ir iagen wellet da wil ich gerne mite ### so svlt ir mir lihen einen suochman ### vnd eteliken braken so wil ich riten in den tan
###### 857 | ### Welt ir niht nemen einen sprach der kvnich zehant ### ich lihe iv welt ir uiere den wol ist bechant ### der walt vnd ovch die stige swa div tier gant ### die iv niht vorewise wider heim riten lant
###### 858 | ### Do reit zvo sin em wibe der riter vil gemeit ### schiere hete Hagene dem kvnige geseit [35b] ### wie er gewinnen wolde den tiwerlichen degen ### sus grozer vntriwe solde nimmer man gepflegen

<<< Übersicht <<< vorige Seite nächste Seite >>>